@@ -129,10 +129,11 @@ def build_package():
         break
 
     print('This dependencies were found:\n\r', *[dep+'\n\r' for dep in deplist])
-    print('installing...')
-    for i, dep in enumerate(deplist):
-        progressBar(i+1, len(deplist))
-        pip_install(PYTHON_FOLDER, dep)
+    print('installing... (it may take a while)')
+    # for i, dep in enumerate(deplist):
+    #     progressBar(i+1, len(deplist))
+    #     pip_install(PYTHON_FOLDER, dep)
+    pip_install(PYTHON_FOLDER, ' '.join(deplist))
     print('')
         
         
